@@ -1,30 +1,25 @@
 package Dist::Zilla::PluginBundle::IDOPEREL;
-
-# ABSTRACT: IDOPEREL's plugin bundle for Dist::Zilla.
+BEGIN {
+  $Dist::Zilla::PluginBundle::IDOPEREL::VERSION = '0.1';
+}
 
 use Moose;
+use Moose::Autobox;
 use namespace::autoclean;
+with 'Dist::Zilla::Role::PluginBundle';
 
-with 'Dist::Zilla::Role::PluginBundle::Easy';
-
-use version 0.77; our $VERSION = version->declare("v0.600.5");
+# ABSTRACT: IDOPEREL's plugin bundle for Dist::Zilla.
 
 use Dist::Zilla::PluginBundle::Filter;
 use Dist::Zilla::PluginBundle::Classic;
 use Dist::Zilla::PluginBundle::Git;
-use Dist::Zilla::Plugin::VersionFromModule;
 use Dist::Zilla::Plugin::MetaJSON;
 use Dist::Zilla::Plugin::MinimumPerl;
-use Dist::Zilla::Plugin::AutoPrereqs;
-use Dist::Zilla::Plugin::Prereqs;
+use Dist::Zilla::Plugin::AutoPrereq;
 use Dist::Zilla::Plugin::NextRelease;
 use Dist::Zilla::Plugin::GithubMeta;
 use Dist::Zilla::Plugin::TestRelease;
 use Dist::Zilla::Plugin::ReadmeFromPod;
-use Dist::Zilla::Plugin::InstallGuide;
-use Dist::Zilla::Plugin::CheckChangesHasContent;
-use Dist::Zilla::Plugin::DistManifestTests;
-use Dist::Zilla::Plugin::Signature;
 
 =head1 NAME
 
@@ -32,7 +27,7 @@ Dist::Zilla::PluginBundle::IDOPEREL - IDOPEREL's plugin bundle for Dist::Zilla.
 
 =head1 VERSION
 
-version v0.600.5
+version 0.1
 
 =head1 SYNOPSIS
 
@@ -51,65 +46,74 @@ This bundle provides the following plugins and bundles:
 	[@Filter]
 	-bundle = @Classic
 	-remove = Readme
-	-remove = PkgVersion
 
-	[@Git]
-	tag_format = %v
-	tag_message = %v
-
-	[VersionFromModule]
-
-	[AutoPrereqs]
-	[Prereqs / ConfigureRequires]
-	version = 0.77
-
-	[CheckChangesHasContent]
-	[DistManifestTests]
-	[GithubMeta]
-	[InstallGuide]
+	[GatherDir]
+	[PruneCruft]
+	[ManifestSkip]
+	[MetaYAML]
 	[MetaJSON]
+	[License]
+	[PkgVersion]
+	[PodVersion]
+	[PodCoverageTests]
+	[PodSyntaxTests]
+	[ExtraTests]
+	[ExecDir]
+	[ShareDir]
+	[MakeMaker]
 	[MinimumPerl]
+	[Manifest]
+	[ConfirmRelease]
+	[UploadToCPAN]
+	[AutoPrereq]
+	[@Git]
 	[NextRelease]
+	[GithubMeta]
 	[ReadmeFromPod]
 	[TestRelease]
-	[Signature]
 
 =head1 INTERNAL METHODS
 
-=head2 configure
+=head2 bundle_config
 
 =cut
 
-sub configure {
-	my $self = shift;
+sub bundle_config {
+	my ($self, $section) = @_;
+	my $class = ref($self) || $self;
 
-	$self->add_bundle(Filter => {
-		-bundle => '@Classic',
-		-remove => [qw/Readme PkgVersion/],
-	});
+	my $arg = $section->{payload};
 
-	$self->add_bundle(Git => {
-		tag_format => '%v',
-		tag_message => '%v',
-	});
-
-	$self->add_plugins(
-		'VersionFromModule',
-
-		[ 'AutoPrereqs' => { skip => $self->payload->{auto_prereqs_skip} } ],
-		[ 'Prereqs' => 'version' => { -phase => 'configure', -type => 'requires', 'version' => 0.77 } ],
-
-		'CheckChangesHasContent',
-		'DistManifestTests',
-		'GithubMeta',
-		'InstallGuide',
-		'MetaJSON',
-		'MinimumPerl',
-		'NextRelease',
-		'ReadmeFromPod',
-		'TestRelease',
-		'Signature'
+	my @plugins = Dist::Zilla::PluginBundle::Filter->bundle_config(
+		{
+			name    => "$class/Classic",
+			payload => {
+				bundle => '@Classic',
+				remove => [qw/Readme/],
+			}
+		}
 	);
+
+	# params
+
+	my $prefix = 'Dist::Zilla::Plugin::';
+	my @extra = map { [ "$class/$prefix$_->[0]" => "$prefix$_->[0]" => $_->[1] ] } (
+		[ AutoPrereq          => { skip  => $arg->{auto_prereq_skip} } ],
+		[ MetaJSON            => {} ],
+		[ MinimumPerl         => {} ],
+		[ NextRelease         => {} ],
+		[ ReadmeFromPod       => {} ],
+		[ TestRelease         => {} ],
+	);
+
+	push (@plugins, @extra);
+
+	# add git plugins
+	push (@plugins,	Dist::Zilla::PluginBundle::Git->bundle_config({ name => "$section->{name}/Git",	payload => {} }));
+
+	eval "require $_->[1]; 1;" or die for @plugins; ## no critic Carp
+
+	return @plugins;
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -151,9 +155,13 @@ L<http://search.cpan.org/dist/Dist-Zilla-PluginBundle-IDOPEREL/>
 
 =back
 
+=head1 ACKNOWLEDGMENTS
+
+Based on L<Dist::Zilla::PluginBundle::PDONELAN> by Patrick Donelan.
+
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010-2011 Ido Perlmuter.
+Copyright 2010 Ido Perlmuter.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
